//
// ---------------------------------------------------------
//               SFX  interface .DLL
// ---------------------------------------------------------
//
// Contains the following functions
//
// HINSTANCE EXPORT LoadSFXLibrary( LPSTR );
//		 Loads an SFX libary by name. returns the library instance to
//		 be used in further SFX calls. If the instance is < 32, see
//		 the WIndows programmer reference for error reasons.
//
// BOOL      EXPORT FreeSFXLibrary( HINSTANCE );
//		 Free a loaded SFX library, return TRUE if no error else FALSE
//
// BOOL      EXPORT GetSFXLibraryInfo( HINSTANCE, LPSFXLIBINFO );
//		 Returns information about a loaded SFX library. See below for
//		 format of the SFX library information table. Returns FALSE
//		 if an error.
//
// BOOL      EXPORT GetSFXName( HINSTANCE, UINT, LPSTR, int );
//		 Returns the descriptive name for an SFX entry in a loaded SFX
//		 library. returns FALSE if an error.
//
// BOOL      EXPORT GetSFXNameId( UINT, LPSTR, int );
//		 Returns the descriptive name for an SFX entry in a loaded SFX
//		 library. Note that SFX identifiers (IDW_)
//      have to be unique for this to function properly.
//      Returns FALSE if an error.
//
// BOOL EXPORT PlayBeep( UINT BeepID )
//      Plays a sound from [sounds] section of WIN.INI,
//      param must be one of
//        MB_OK							"SystemDefault" sound
//        MB_ICONASTERISK				"SystemAsterisk" sound
//        MB_ICONEXCLAMATION			"SystemExclamation" sound
//        MB_ICONSTOP		or
//        MB_ICONHAND					"SystemHand" sound
//        MB_ICONQUESTION				"SystemQuestion" sound
//      Returns TRUE if sound STARTED playing, else FALSE.
//
// BOOL EXPORT PlayWinIni( LPSTR KeyName )
//      Plays a sound by name from the [sounds] section of WIN.INI,
//      param must be one of
//					"SystemAsterisk"
//					"SystemHand"
//					"SystemDefault"
//					"SystemExclamation"
//					"SystemQuestion"
//					"SystemExit"
//					"SystemStart"
//			or one you added, such as the DCT files
//					"ctAddTestToRun"
//					"ctBlackHole"
//					"ctTestFinish"
//      Returns TRUE if sound FINISHED playing, else FALSE
//
// BOOL EXPORT PlaySFX( HINSTANCE, UINT );
//      Plays a sound from a loaded SFX library, for predefined resource
//		 see the SFXDLL.H include file. Else you can add to the resource
//      file with a compatible browser. Note that pre-included files are
//      automatically MAKEINTRESOURCE'd, but those you add will require
//      the string name.
//      Returns TRUE if sound FINISHED playing, else FALSE
//
// BOOL EXPORT PlaySFXId( UINT );
//      Plays a sound from a loaded SFX library, for predefined resource
//		 see the SFXDLL.H include file. Note that SFX identifiers (IDW_)
//      have to be unique for this to function properly.
//      Returns TRUE if sound FINISHED playing, else FALSE
//
// BOOL EXPORT PlayFile( LPSTR FileName )
//      Plays a sound from the named file. Note that you can also
//      supply one of the names from the PlayWinIni parameter list
//      instead of that of a .WAV file.
//      Returns TRUE if sound FINISHED playing, else FALSE
//
// ---------------------------------------------------------

// ---------------------------------------------------------
//        Macro and other defines
// ---------------------------------------------------------

#ifdef RC_INVOKED
#define	ID(x) x
#else
#define ID(x) MAKEINTRESOURCE(x)
#endif

#define NOREF(x) x					// For -W3 compatibility

#define PRIVATE NEAR
#define PUBLIC  FAR PASCAL
#define EXPORT  FAR PASCAL

// ---------------------------------------------------------
//        Resource identifiers ( the .WAV resources )
// ---------------------------------------------------------

// ---------------------------------------------------------
// Mandatory RCDATA Identifier
// ---------------------------------------------------------

#define		IDI_SFXINFO	 1

// Arnie, range allocated is 1-100

#define		IDW_BLEED		 1
#define		IDW_CLOTHES	 2

// Bart, range allocated 101-200

#define		IDW_BUTKIS		 101
#define		IDW_CERTNLY	 102
#define		IDW_EATSHORT	103
#define		IDW_BART		 104
#define		IDW_DAMNED		 105

// HAL, range allocated 201-299

#define		IDW_ANSWER		 201
#define		IDW_ARE_SURE 202
#define		IDW_CNT_ALOW 203
#define		IDW_DECISION 204
#define		IDW_DIFFIC		 205
#define		IDW_RATHER		 206
#define		IDW_FAILURE	 207
#define		IDW_FEELBETR	208
#define		IDW_HAL			 209
#define		IDW_OPER		 210
#define		IDW_YOUARE		 211
#define		IDW_UPSET		 212
#define		IDW_THIS_CON 213
#define		IDW_STOP		 214
#define		IDW_STRESS		 215
#define		IDW_QUESTION	216
#define		IDW_ERROR		 217
#define		IDW_GOODBYE	 218
#define		IDW_JUST_WHT	219
#define		IDW_MIND		 220
#define		IDW_MOMENT		 221
#define		IDW_NO_WORRY	222

// Film quotes, range allocated 301-399

#define		IDW_CLINT		 301
#define		IDW_DAMN		 302
#define		IDW_EVIL		 303
#define		IDW_MOUTH		 304
#define		IDW_NUMBER5	 305
#define		IDW_OFSTARS	 306
#define		IDW_ROBOCOP	 307
#define		IDW_THEY		 308
#define		IDW_TOYS		 309
#define		IDW_WONDRFL	 310

// Startrek, range allocated 401-499

#define		IDW_NOMAD1		 401
#define		IDW_NOMAD2		 402
#define		IDW_NOMAD3		 403
#define		IDW_NOMAD4		 404
#define		IDW_NOMAD5		 405
#define		IDW_NOMAD6		 406
#define		IDW_NOMAD7		 407
#define		IDW_FASINATE	408
#define		IDW_ACCESSNG	409
#define		IDW_ASYOUBEL	410
#define		IDW_CAPT_LOG	411
#define		IDW_CURERAIN	412
#define		IDW_DNTTRUST	413
#define		IDW_DRNOTAB	 414
#define		IDW_MAKEITSO	415
#define		IDW_THISCAPT	416

// Music, range allocated 501-599

#define		IDW_CHIMES		 501
#define		IDW_CHORD		 502
#define		IDW_CONGA		 503
#define		IDW_DRAGNET	 504
#define		IDW_FTROOP		 505
#define		IDW_INTRO		 506
#define		IDW_OH_YEAH	 507
#define		IDW_ORGAN		 508
#define		IDW_TADA		 509

// Star Wars, range allocated 601-699

#define		IDW_BIDDING	 601
#define		IDW_DARTH		 602
#define		IDW_HAIL		 603

// Animals, range allocated 701-799

#define		IDW_BARK1		 701
#define		IDW_BARK2		 702
#define		IDW_BARK3		 703
#define		IDW_BARK4		 704
#define		IDW_BATS		 705
#define		IDW_CAT			 706
#define		IDW_CROW		 707
#define		IDW_DOGS		 708
#define		IDW_FROGS		 709
#define		IDW_GROWL1		 710
#define		IDW_GROWL10	 711
#define		IDW_RUFF		 712

// Quotes, range allocated 801-899

#define		IDW_BRAIN		 801
#define		IDW_BUTHED		 802
#define		IDW_BUTT		 803
#define		IDW_CURLY		 804
#define		IDW_DIRECT		 805
#define		IDW_DOCTOR		 806
#define		IDW_DOILOOK	 807
#define		IDW_DONTJERK	808
#define		IDW_FALLEN		 809
#define		IDW_FLAGUP		 810
#define		IDW_GAMEOVER	811
#define		IDW_GOD			 812
#define		IDW_GOODEVEN	813
#define		IDW_REAGAN		 814
#define		IDW_SINNED		 815

// Things, range allocated 901-999

#define		IDW_BANGBANG	901
#define		IDW_BREAK		 902
#define		IDW_BUZZER		 903
#define		IDW_CLANK		 904
#define		IDW_CREAK		 905
#define		IDW_CREAK1		 906
#define		IDW_CREAK2		 907
#define		IDW_CREAK3		 908
#define		IDW_DING		 909
#define		IDW_DOOR1		 910
#define		IDW_DOOR		 911
#define		IDW_DROP		 912
#define		IDW_EXPLODE	 913
#define		IDW_EXPLODE2	914
#define		IDW_EXPLOSIO	915
#define		IDW_GATE		 916
#define		IDW_GHOST2		 917
#define		IDW_HIT			 918
#define		IDW_LASER		 919
#define		IDW_MGUN		 920
#define		IDW_PISTOL		 921
#define		IDW_SIREN		 922
#define		IDW_SLOTS		 923
#define		IDW_STORM		 924
#define		IDW_THUNDER2	925
#define		IDW_THUNDER	 926
#define		IDW_TINK		 927

// Human sounds, range allocated 1001-1099

#define		IDW_AHA			 1001
#define		IDW_BLEACH		 1002
#define		IDW_BOO			 1003
#define		IDW_BURP		 1004
#define		IDW_CLSSND		 1005
#define		IDW_COOL		 1006
#define		IDW_EAT1		 1007
#define		IDW_EAT3		 1008
#define		IDW_EAT4		 1009
#define		IDW_FART		 1010
#define		IDW_GLUG		 1011
#define		IDW_GROAN1		 1012
#define		IDW_GROAN2		 1013
#define		IDW_GROAN3		 1014
#define		IDW_NYUK		 1015
#define		IDW_SCREAM2	 1016
#define		IDW_THRILAFF	1017
#define		IDW_WOOB		 1018

// Miscellaneous sounds, range allocated 1101-1199

#define		IDW_BBCNEWS	 1101
#define		IDW_BEAT		 1102
#define		IDW_CHIKA		 1103
#define		IDW_CLP			 1104
#define		IDW_DESTRUCT	1105
#define		IDW_DEVI		 1106
#define		IDW_DISKJKT	 1107
#define		IDW_FABULOUS	1108
#define		IDW_FEEDME		 1109
#define		IDW_FREDDYK	 1110
#define		IDW_GWN			 1111
#define		IDW_HELLO1		 1112
#define		IDW_POONTANG	1113
#define		IDW_RADICAL	 1114
#define		IDW_STD			 1115

// Telephone operator, range allocated 1201-1299

#define		IDW_ZERO		 1201
#define		IDW_ONE			 1202
#define		IDW_TWO			 1203
#define		IDW_THREE		 1204
#define		IDW_FOUR		 1205
#define		IDW_FIVE		 1206
#define		IDW_SIX			 1207
#define		IDW_SEVEN		 1208
#define		IDW_EIGHT		 1209
#define		IDW_NINE		 1210
#define		IDW_CHANGED	 1211
#define		IDW_HASBEEN	 1212
#define		IDW_TEMPDISC	1213
#define		IDW_MAKENOTE	1214
#define		IDW_NOFURTH	 1215
#define		IDW_NOINCOME	1216

// ---------------------------------------------------------
//        SFX LIbrary information
// ---------------------------------------------------------

typedef struct tagSFXLIBINFO
						{
						 HINSTANCE  hSFXLibInstance;
						 UINT       uNumSFX;
						 UINT			uFirstSFX;
						 UINT			uLastSFX;
						 UINT			uSFXIncrement;
						 char			szSFXLibName[128];
						 char			szSFXLibDesc[128];
						} SFXLIBINFO, FAR * LPSFXLIBINFO;

// ---------------------------------------------------------
//        Function prototypes
// ---------------------------------------------------------

HINSTANCE EXPORT LoadSFXLibrary( LPSTR );
BOOL      EXPORT FreeSFXLibrary( HINSTANCE );
BOOL      EXPORT GetSFXLibraryInfo( HINSTANCE, LPSFXLIBINFO );
BOOL      EXPORT GetSFXName( HINSTANCE, UINT, LPSTR, int );
BOOL      EXPORT GetSFXNameId( UINT, LPSTR, int );

BOOL      EXPORT PlayBeep( UINT );
BOOL      EXPORT PlayWinIni( LPSTR );
BOOL      EXPORT PlaySFX( HINSTANCE, UINT );
BOOL      EXPORT PlaySFXId( UINT );
BOOL      EXPORT PlayFile( LPSTR );

BOOL PUBLIC LIBMAIN( HINSTANCE, WORD, WORD, LPSTR );
int  EXPORT WEP( int );
